==> jc-1.4.0.tar.gz: java/util/Collections__24UnmodifiableRandomAccessList.h <==
// final class java.util.Collections$UnmodifiableRandomAccessList

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2126b28aee607999 java_util_Collections__24UnmodifiableCollection
// @dep_class f6337dee44795dd7 java_util_Collections__24UnmodifiableList
// @dep_class 85abf76c7de1ef57 java_util_Collections__24UnmodifiableRandomAccessList

// header file dependencies
// @dep_header java_util_Collections__24UnmodifiableList

#include "java/util/Collections__24UnmodifiableList.h"

#ifndef _JC_java_util_Collections__24UnmodifiableRandomAccessList_H_
#define _JC_java_util_Collections__24UnmodifiableRandomAccessList_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;

// Typedefs
typedef struct _jc_java_util_Collections__24UnmodifiableRandomAccessList$sub_refs	_jc_java_util_Collections__24UnmodifiableRandomAccessList$sub_refs;
typedef struct _jc_java_util_Collections__24UnmodifiableRandomAccessList$sub_nonrefs	_jc_java_util_Collections__24UnmodifiableRandomAccessList$sub_nonrefs;
typedef struct _jc_java_util_Collections__24UnmodifiableRandomAccessList$refs	_jc_java_util_Collections__24UnmodifiableRandomAccessList$refs;
typedef struct _jc_java_util_Collections__24UnmodifiableRandomAccessList$nonrefs	_jc_java_util_Collections__24UnmodifiableRandomAccessList$nonrefs;
typedef struct _jc_java_util_Collections__24UnmodifiableRandomAccessList$object	_jc_java_util_Collections__24UnmodifiableRandomAccessList$object;

typedef struct _jc_java_util_Collections__24UnmodifiableRandomAccessList$fields_struct	_jc_java_util_Collections__24UnmodifiableRandomAccessList$fields_struct;
typedef const struct _jc_java_util_Collections__24UnmodifiableRandomAccessList$vmethods	_jc_java_util_Collections__24UnmodifiableRandomAccessList$vmethods;
typedef const struct _jc_java_util_Collections__24UnmodifiableRandomAccessList$vtable	_jc_java_util_Collections__24UnmodifiableRandomAccessList$vtable;
typedef const struct _jc_java_util_Collections__24UnmodifiableRandomAccessList$vtype	_jc_java_util_Collections__24UnmodifiableRandomAccessList$vtype;

// Class fields structure
struct _jc_java_util_Collections__24UnmodifiableRandomAccessList$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_Collections__24UnmodifiableRandomAccessList$fields_struct _jc_java_util_Collections__24UnmodifiableRandomAccessList$class_fields;

// Constructors
extern void _jc_java_util_Collections__24UnmodifiableRandomAccessList$method$_init$dd8ff073a2c7f994(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableRandomAccessList$object *, struct _jc_object *);

// Virtual methods structure
struct _jc_java_util_Collections__24UnmodifiableRandomAccessList$vmethods {
};

// Vtable
struct _jc_java_util_Collections__24UnmodifiableRandomAccessList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_Collections__24UnmodifiableCollection$vmethods	java_util_Collections__24UnmodifiableCollection;
	_jc_java_util_Collections__24UnmodifiableList$vmethods	java_util_Collections__24UnmodifiableList;
	_jc_java_util_Collections__24UnmodifiableRandomAccessList$vmethods	java_util_Collections__24UnmodifiableRandomAccessList;
};

// Vtype
struct _jc_java_util_Collections__24UnmodifiableRandomAccessList$vtype {
	_jc_type			type;
	_jc_java_util_Collections__24UnmodifiableRandomAccessList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_Collections__24UnmodifiableRandomAccessList$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_Collections__24UnmodifiableRandomAccessList$refs {
    _jc_java_util_Collections__24UnmodifiableRandomAccessList$sub_refs	java_util_Collections__24UnmodifiableRandomAccessList;
    _jc_java_util_Collections__24UnmodifiableList$sub_refs	java_util_Collections__24UnmodifiableList;
    _jc_java_util_Collections__24UnmodifiableCollection$sub_refs	java_util_Collections__24UnmodifiableCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_Collections__24UnmodifiableRandomAccessList$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_Collections__24UnmodifiableRandomAccessList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_Collections__24UnmodifiableCollection$sub_nonrefs	java_util_Collections__24UnmodifiableCollection;
    _jc_java_util_Collections__24UnmodifiableList$sub_nonrefs	java_util_Collections__24UnmodifiableList;
    _jc_java_util_Collections__24UnmodifiableRandomAccessList$sub_nonrefs	java_util_Collections__24UnmodifiableRandomAccessList;
};

// Object instance structure
struct _jc_java_util_Collections__24UnmodifiableRandomAccessList$object {
	_jc_java_util_Collections__24UnmodifiableRandomAccessList$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_Collections__24UnmodifiableRandomAccessList$vtype	*vtype;
	_jc_java_util_Collections__24UnmodifiableRandomAccessList$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_Collections__24UnmodifiableRandomAccessList$vtype _jc_java_util_Collections__24UnmodifiableRandomAccessList$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_Collections__24UnmodifiableRandomAccessList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_Collections__24UnmodifiableRandomAccessList$class_object;

#endif	/* _JC_java_util_Collections__24UnmodifiableRandomAccessList_H_ */

==> jc-1.4.6.tar.gz: java/util/Collections__24UnmodifiableRandomAccessList.h <==
// final class java.util.Collections$UnmodifiableRandomAccessList

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2126b28aee607999 java_util_Collections__24UnmodifiableCollection
// @dep_class f6337dee44795dd7 java_util_Collections__24UnmodifiableList
// @dep_class 85abf76c7de1ef57 java_util_Collections__24UnmodifiableRandomAccessList

// header file dependencies
// @dep_header java_util_Collections__24UnmodifiableList

#include "java/util/Collections__24UnmodifiableList.h"

#ifndef _JC_java_util_Collections__24UnmodifiableRandomAccessList_H_
#define _JC_java_util_Collections__24UnmodifiableRandomAccessList_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;

// Typedefs
typedef struct _jc_java_util_Collections__24UnmodifiableRandomAccessList$sub_refs	_jc_java_util_Collections__24UnmodifiableRandomAccessList$sub_refs;
typedef struct _jc_java_util_Collections__24UnmodifiableRandomAccessList$sub_nonrefs	_jc_java_util_Collections__24UnmodifiableRandomAccessList$sub_nonrefs;
typedef struct _jc_java_util_Collections__24UnmodifiableRandomAccessList$refs	_jc_java_util_Collections__24UnmodifiableRandomAccessList$refs;
typedef struct _jc_java_util_Collections__24UnmodifiableRandomAccessList$nonrefs	_jc_java_util_Collections__24UnmodifiableRandomAccessList$nonrefs;
typedef struct _jc_java_util_Collections__24UnmodifiableRandomAccessList$object	_jc_java_util_Collections__24UnmodifiableRandomAccessList$object;

typedef struct _jc_java_util_Collections__24UnmodifiableRandomAccessList$fields_struct	_jc_java_util_Collections__24UnmodifiableRandomAccessList$fields_struct;
typedef const struct _jc_java_util_Collections__24UnmodifiableRandomAccessList$vmethods	_jc_java_util_Collections__24UnmodifiableRandomAccessList$vmethods;
typedef const struct _jc_java_util_Collections__24UnmodifiableRandomAccessList$vtable	_jc_java_util_Collections__24UnmodifiableRandomAccessList$vtable;
typedef const struct _jc_java_util_Collections__24UnmodifiableRandomAccessList$vtype	_jc_java_util_Collections__24UnmodifiableRandomAccessList$vtype;

// Class fields structure
struct _jc_java_util_Collections__24UnmodifiableRandomAccessList$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_Collections__24UnmodifiableRandomAccessList$fields_struct _jc_java_util_Collections__24UnmodifiableRandomAccessList$class_fields;

// Constructors
extern void _jc_java_util_Collections__24UnmodifiableRandomAccessList$method$_init$dd8ff073a2c7f994(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableRandomAccessList$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_util_Collections__24UnmodifiableRandomAccessList$vmethods {
};

// Vtable
struct _jc_java_util_Collections__24UnmodifiableRandomAccessList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_Collections__24UnmodifiableCollection$vmethods	java_util_Collections__24UnmodifiableCollection;
	_jc_java_util_Collections__24UnmodifiableList$vmethods	java_util_Collections__24UnmodifiableList;
	_jc_java_util_Collections__24UnmodifiableRandomAccessList$vmethods	java_util_Collections__24UnmodifiableRandomAccessList;
};

// Vtype
struct _jc_java_util_Collections__24UnmodifiableRandomAccessList$vtype {
	_jc_type			type;
	_jc_java_util_Collections__24UnmodifiableRandomAccessList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_Collections__24UnmodifiableRandomAccessList$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_Collections__24UnmodifiableRandomAccessList$refs {
    _jc_java_util_Collections__24UnmodifiableRandomAccessList$sub_refs	java_util_Collections__24UnmodifiableRandomAccessList;
    _jc_java_util_Collections__24UnmodifiableList$sub_refs	java_util_Collections__24UnmodifiableList;
    _jc_java_util_Collections__24UnmodifiableCollection$sub_refs	java_util_Collections__24UnmodifiableCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_Collections__24UnmodifiableRandomAccessList$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_Collections__24UnmodifiableRandomAccessList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_Collections__24UnmodifiableCollection$sub_nonrefs	java_util_Collections__24UnmodifiableCollection;
    _jc_java_util_Collections__24UnmodifiableList$sub_nonrefs	java_util_Collections__24UnmodifiableList;
    _jc_java_util_Collections__24UnmodifiableRandomAccessList$sub_nonrefs	java_util_Collections__24UnmodifiableRandomAccessList;
};

// Object instance structure
struct _jc_java_util_Collections__24UnmodifiableRandomAccessList$object {
	_jc_java_util_Collections__24UnmodifiableRandomAccessList$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_Collections__24UnmodifiableRandomAccessList$vtype	*vtype;
	_jc_java_util_Collections__24UnmodifiableRandomAccessList$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_Collections__24UnmodifiableRandomAccessList$vtype _jc_java_util_Collections__24UnmodifiableRandomAccessList$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_Collections__24UnmodifiableRandomAccessList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_Collections__24UnmodifiableRandomAccessList$class_object;

#endif	/* _JC_java_util_Collections__24UnmodifiableRandomAccessList_H_ */
